import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, SecurityContext, Directive, HostBinding, Component, ChangeDetectionStrategy, EventEmitter, ElementRef, Host, Input, Output, TemplateRef, Self, ViewChild, NgModule } from '@angular/core';
import * as i1$1 from '@angular/common';
import { CommonModule } from '@angular/common';
import { HttpClientModule } from '@angular/common/http';
import { __rest } from 'tslib';
import { takeUntil, filter, map, pluck, tap } from 'rxjs/operators';
import { BehaviorSubject, of, Subject } from 'rxjs';
import { trigger, transition, query, stagger, animate, style, keyframes, state } from '@angular/animations';
import * as i1 from '@angular/platform-browser';

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
function iniTogglerFn() {
    return [];
}
const INI_STATE = new InjectionToken('Accordion Initial Items Open state provider token', { factory: iniTogglerFn });
class AccordionOpenService extends BehaviorSubject {
    constructor(iniState = []) {
        super(iniState);
        this.setItemsOpen = (itemsStats) => this.next(itemsStats);
        this.close = () => {
            this.complete();
            super.unsubscribe();
        };
    }
    get itemsOpen$() {
        return this.asObservable();
    }
    get itemsOpenSnapshot() {
        return this.value;
    }
}
AccordionOpenService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionOpenService, deps: [{ token: INI_STATE }], target: i0.ɵɵFactoryTarget.Injectable });
AccordionOpenService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionOpenService });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionOpenService, decorators: [{
            type: Injectable
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Inject,
                        args: [INI_STATE]
                    }] }];
    } });

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
const accordionAnimations = {
    accordItemsIn: trigger('accordItemsIn', [
        transition('* => *', [
            query(':leave', [
                stagger(-25, [
                    animate('.3s', style({
                        opacity: 0,
                        transform: 'scale(0.7, 0.7) translateY(-3rem)',
                    })),
                ]),
            ], { optional: true }),
            query(':enter', [
                style({ opacity: 0, transform: 'scale(0.7, 0.7) translateY(-3rem)' }),
                stagger(25, [
                    animate('.3s ease-out', keyframes([
                        style({ offset: 0, opacity: 0 }),
                        style({
                            offset: 0.2,
                            opacity: 0.1,
                            transform: 'scale(0.85, 0.85) translateY(-4rem)',
                        }),
                        style({
                            offset: 0.5,
                            opacity: 0.8,
                            transform: 'scale(0.9, 0.9) translateY(3rem)',
                        }),
                        style({ offset: 1, opacity: 1, transform: 'none' }),
                    ])),
                ]),
            ], { optional: true }),
        ]),
    ]),
    spinnerIn: trigger('spinnerIn', [
        transition('void => *', [
            query('.loader', animate('.5s ease-out', keyframes([
                style({
                    offset: 0,
                    opacity: 0,
                    transformOrigin: 'bottom right',
                    height: 0,
                    transform: 'translateY(-100px) scale(0, 0)',
                }),
                style({
                    offset: 0.8,
                    opacity: 0.6,
                    height: 0,
                    transform: 'translateY(40px) scale(0.5, 0.5)',
                }),
                style({
                    offset: 1,
                    opacity: 1,
                    height: '*',
                    transform: 'translateY(0) scale(1, 1)',
                }),
            ])), { optional: true }),
        ]),
    ]),
};
const accordionItemAnimations = {
    accordionItemBodyHeightCollapse: trigger('openClose', [
        state('closed', style({
            height: '0',
            opacity: '0',
            visibility: 'collapse',
        })),
        state('opened', style({
            height: '*',
            opacity: '1',
            visibility: 'visible',
        })),
        transition('opened <=> closed', animate('.3s ease-out')),
    ]),
};

const pluckIToggler = (_a) => {
    var { itemId, isOpen } = _a, rest = __rest(_a, ["itemId", "isOpen"]);
    return ({ itemId, isOpen });
};
const pluckOpenTogglesIdsToStr = (toggles) => toggles
    .filter((t) => t.isOpen === true)
    .map((t) => t.itemId)
    .join(',');

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
const imgBase64ToBlob = (Base64Image, imageType = 'image/png') => {
    const parts = Base64Image.split(';base64,');
    const decodedData = window.atob(parts[1]);
    const uInt8Array = new Uint8Array(decodedData.length);
    for (let i = 0; i < decodedData.length; ++i) {
        uInt8Array[i] = decodedData.charCodeAt(i);
    }
    return new Blob([uInt8Array], { type: imageType });
};
const svgToBase64src = (rawSvg) => 'data:image/svg+xml;base64,' + btoa(rawSvg);
const prepRes = (item, sanitizer) => sanitizer.bypassSecurityTrustResourceUrl(item);
const sanitizeHTML = (item, sanitizer) => !!item && sanitizer.sanitize(SecurityContext.HTML, item);
const getSvgSafeRes = (file, sanitizer) => prepRes(svgToBase64src(file), sanitizer);
const getPngSafeRes = (file, sanitizer) => prepRes(URL.createObjectURL(imgBase64ToBlob(file)), sanitizer);
const blobToSafeRes = (blob, sanitizer) => prepRes(URL.createObjectURL(blob), sanitizer);
const bodyWithTmpl = (item) => !!item && typeof item !== 'string' && !!item.itemTemplate;
const getItemBodyTemplate = (item, defaultTmpl) => (!!bodyWithTmpl(item) ? item.itemTemplate : defaultTmpl);
const getItemBodyCtx = (item) => (bodyWithTmpl(item) && typeof item.itemBody === 'string' ? item.itemBody : item);

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */

/* eslint-disable max-len */
/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
const logo_svg = '<svg width="50" height="50" viewBox="0 0 50 50" fill="white" xmlns="http://www.w3.org/2000/svg"><path fill-rule="evenodd" clip-rule="evenodd" d="M5 0C2.23858 0 0 2.23858 0 5V45C0 47.7614 2.23858 50 5 50H45C47.7614 50 50 47.7614 50 45V5C50 2.23858 47.7614 0 45 0H5ZM11 10C10.4477 10 10 10.4477 10 11V15C10 15.5523 10.4477 16 11 16H39C39.5523 16 40 15.5523 40 15V11C40 10.4477 39.5523 10 39 10H11ZM10 23C10 22.4477 10.4477 22 11 22H39C39.5523 22 40 22.4477 40 23V27C40 27.5523 39.5523 28 39 28H11C10.4477 28 10 27.5523 10 27V23ZM11 34C10.4477 34 10 34.4477 10 35V39C10 39.5523 10.4477 40 11 40H32C32.5523 40 33 39.5523 33 39V35C33 34.4477 32.5523 34 32 34H11Z"/></svg>';
const arrow_down = '<svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="white" width="48px" height="48px"><path d="M7.41 8.59L12 13.17l4.59-4.58L18 10l-6 6-6-6 1.41-1.41z"/><path d="M0 0h24v24H0V0z" fill="none"/></svg>';

var ImgClasses;
(function (ImgClasses) {
    ImgClasses["LOGO"] = "accord-item__header--start-img";
    ImgClasses["ENDING"] = "accord-item__header--end-img";
})(ImgClasses || (ImgClasses = {}));
var ImgLoadClass;
(function (ImgLoadClass) {
    ImgLoadClass["SUCCESS"] = "img-loaded__success";
    ImgLoadClass["ALTER"] = "img-load__alter";
})(ImgLoadClass || (ImgLoadClass = {}));
class AccordionItemImgDirective {
    constructor(el, renderer, zone, sanitizer) {
        this.el = el;
        this.renderer = renderer;
        this.zone = zone;
        this.sanitizer = sanitizer;
        this._baseLogoImg = getSvgSafeRes(logo_svg, this.sanitizer);
        this._baseChevronImg = getSvgSafeRes(arrow_down, this.sanitizer);
        this._isSet = false;
        this._needToRecheck = false;
        this.onLoad = (_a) => {
            var { target } = _a, rest = __rest(_a, ["target"]);
            return this._setLoadSuccess(target);
        };
        this.onError = (_a) => {
            var { target } = _a, rest = __rest(_a, ["target"]);
            this._setLoadAlter(target);
            if (target.classList.contains(ImgClasses.LOGO)) {
                // this.setItemHeaderImgSrc(target, this._baseLogoImg);
                this._setItemHeaderImgSafeSrc(this._baseLogoImg);
            }
            else if (target.classList.contains(ImgClasses.ENDING)) {
                // this.setItemHeaderImgSrc(target, this._baseChevronImg);
                this._setItemHeaderImgSafeSrc(this._baseChevronImg);
            }
            else {
                return console.log('Not an Accordion Item header image');
            }
        };
        this._doOpenCloseSrcRecheck = () => this.zone.runOutsideAngular(() => { var _a; return (this._src = ((_a = this._nativeImgEl) === null || _a === void 0 ? void 0 : _a.classList.contains('open')) ? this._closeSign : this._openSign); });
        this._setItemHeaderImgSrc = (imgRef, src) => this.renderer.setAttribute(imgRef, 'src', src);
        this._setItemHeaderImgSafeSrc = (src) => {
            this._src = src;
            return this._setNoRecheck();
        };
        this._readElDataSet = (attr) => { var _a; return (_a = this._nativeImgEl) === null || _a === void 0 ? void 0 : _a.dataset[attr]; };
        this._setLoadSuccess = (target) => {
            target.classList.add(ImgLoadClass.SUCCESS);
            this._isSet = true;
        };
        this._setLoadAlter = (target) => {
            target.classList.add(ImgLoadClass.ALTER);
            this._setNoRecheck();
        };
        this._isImgOpenClose = () => !!this._closeSign && !!this._closeSign.length && !!this._openSign && !!this._openSign.length;
        this._isLogoImg = () => { var _a; return (_a = this._nativeImgEl) === null || _a === void 0 ? void 0 : _a.classList.contains(ImgClasses.LOGO); };
        this._isCloserImg = () => { var _a; return (_a = this._nativeImgEl) === null || _a === void 0 ? void 0 : _a.classList.contains(ImgClasses.ENDING); };
        this._setNoRecheck = () => {
            this._isSet = true;
            this._needToRecheck = false;
        };
    }
    get src() {
        return this._src;
    }
    ngAfterViewInit() {
        this._nativeImgEl = this.el.nativeElement;
    }
    ngAfterContentChecked() {
        var _a, _b;
        if (this._isSet && !this._needToRecheck)
            return;
        if (this._isSet && this._needToRecheck)
            return this._doOpenCloseSrcRecheck();
        if (this._isLogoImg()) {
            // this._src = this.readElDataSet('src') || this._baseLogoImg;
            // return this.setNoRecheck();
            return this._setItemHeaderImgSafeSrc(this._readElDataSet('src') || this._baseLogoImg);
        }
        else if (this._isCloserImg()) {
            this._openSign = (_a = this._readElDataSet('opensrc')) !== null && _a !== void 0 ? _a : undefined;
            this._closeSign = (_b = this._readElDataSet('closesrc')) !== null && _b !== void 0 ? _b : undefined;
            if (!this._isImgOpenClose()) {
                // this._src = this._baseChevronImg;
                // return this.setNoRecheck();
                return this._setItemHeaderImgSafeSrc(this._baseChevronImg);
            }
            else {
                if (this._openSign !== this._closeSign) {
                    this._needToRecheck = true;
                }
                this._isSet = true;
                return;
            }
        }
    }
}
AccordionItemImgDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemImgDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }, { token: i0.NgZone }, { token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Directive });
AccordionItemImgDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.9", type: AccordionItemImgDirective, selector: ".accord-item__header-img", host: { listeners: { "load": "onLoad($event)", "error": "onError($event)" }, properties: { "attr.loading": "\"lazy\"", "attr.src": "this.src" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemImgDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '.accord-item__header-img',
                    host: {
                        '(load)': 'onLoad($event)',
                        '(error)': 'onError($event)',
                        '[attr.loading]': '"lazy"',
                    },
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }, { type: i0.NgZone }, { type: i1.DomSanitizer }]; }, propDecorators: { src: [{
                type: HostBinding,
                args: ['attr.src']
            }] } });

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
class AccordionItemComponent {
    constructor() {
        this.getItemBodyCtx = getItemBodyCtx;
        this.getItemBodyTemplate = getItemBodyTemplate;
        this.isOpen$ = of(false);
    }
    startAnim(e) {
        e.element.style.willChange = 'height, opacity, visibility';
        const classes = e.element.classList;
        if (e.fromState === 'void')
            classes === null || classes === void 0 ? void 0 : classes.add('closed');
        if (e.fromState === 'closed' && e.toState === 'opened')
            classes.replace('closed', 'opened');
    }
    doneAnim(e) {
        e.element.style.willChange = 'auto';
        const classes = e.element.classList;
        if (e.fromState == 'opened' && e.toState == 'closed')
            classes.replace('opened', 'closed');
    }
}
AccordionItemComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
AccordionItemComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.9", type: AccordionItemComponent, selector: "ngxd-accordion-item", ngImport: i0, template: "<!--\n/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */\n-->\n<ng-container *ngTemplateOutlet=\"itemTpl; context: { $implicit: isOpen$ | async }\"></ng-container>\n\n<ng-template #itemTpl let-isOpen>\n\t<article class=\"accord-item\">\n\t\t<header class=\"accord-item__header\" [class.opened]=\"isOpen\">\n\t\t\t<ng-container *ngTemplateOutlet=\"headerDefaultTmpl; context: { $implicit: isOpen }\"></ng-container>\n\t\t</header>\n\t\t<section class=\"accord-item__body\" [@openClose]=\"isOpen ? 'opened' : 'closed'\" (@openClose.start)=\"startAnim($event)\" (@openClose.done)=\"doneAnim($event)\">\n\t\t\t<ng-container *ngTemplateOutlet=\"getItemBodyTemplate($any(item.body), bodyDefaultTmpl); context: { $implicit: getItemBodyCtx($any(item.body)) }\"></ng-container>\n\t\t</section>\n\t</article>\n</ng-template>\n\n<ng-template #headerDefaultTmpl let-isOpen>\n\t<div class=\"header--control accord-item__logo\">\n\t\t<span class=\"accord-item__header--start\">\n\t\t\t<img class=\"accord-item__header-img accord-item__header--start-img\" />\n\t\t\t<span *ngIf=\"item.itemNum\">{{ item.itemNum }}.</span>\n\t\t</span>\n\t</div>\n\t<div class=\"header--control accord-item__title\">\n\t\t{{ item.title }}\n\t</div>\n\t<div class=\"header--control accord-item__collapse\">\n\t\t<span class=\"accord-item__header--end\" [class.active]=\"isOpen\">\n\t\t\t<!-- NOTE: img 'src' attr is bound in the `accordion-item-img.directive` -->\n\t\t\t<img class=\"accord-item__header-img accord-item__header--end-img\" [ngClass]=\"{ open: isOpen, close: !isOpen }\" />\n\t\t</span>\n\t</div>\n</ng-template>\n\n<ng-template #bodyDefaultTmpl let-defctx>\n\t{{ defctx }}\n\t<ng-content select=\".accord-item__footer\"></ng-content>\n</ng-template>\n", styles: [":host{--color-white: #fff;--ngxd-head-item-color: #056;--ngxd-head-item-color--active: #0095b3;--ngxd-head-item-color--opened: #002b33}/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */.accord-item{display:block;box-sizing:border-box;min-width:10rem;min-height:1rem;overflow:hidden}.accord-item .accord-item__header{display:flex;position:relative;flex-direction:row;min-height:1rem;max-height:50px;overflow:visible;transition:.6s ease;background-color:var(--ngxd-head-item-color);color:var(--color-white);-webkit-user-select:none;user-select:none}.accord-item .accord-item__header:hover,.accord-item .accord-item__header:active{background-color:var(--ngxd-head-item-color--active)!important;cursor:pointer}.accord-item .accord-item__header.opened{background-color:var(--ngxd-head-item-color--opened)!important}.accord-item .accord-item__header .accord-item__header--btn{max-width:2rem;border:none;background:transparent;font-size:x-large;text-align:center;vertical-align:middle}.accord-item .accord-item__header .accord-item__collapse--btn{padding-right:1px}.accord-item .accord-item__header .accord-item__header--start,.accord-item .accord-item__header .accord-item__header--end{display:flex;flex:0 0 1rem;align-items:center;justify-content:center;max-width:1.5rem;padding-left:1px}.accord-item .accord-item__header .accord-item__header--start .accord-item__header--start-img,.accord-item .accord-item__header .accord-item__header--end .accord-item__header--start-img{max-width:1rem;margin-right:.5rem}.accord-item .accord-item__header .accord-item__header--start>img,.accord-item .accord-item__header .accord-item__header--end>img{max-width:1.5rem}.accord-item .accord-item__header .accord-item__header--end{padding-right:1px;padding-left:0;will-change:transform}.accord-item .accord-item__header .accord-item__header--end.active{transform:rotate(180deg);transition:transform .3s ease-out}.accord-item .accord-item__header .accord-item__header--end:not(.active){transform:rotate(0);transition:transform .3s ease-out}.accord-item .accord-item__header .header--control{display:flex;align-items:center;margin:.1rem;padding:1rem;-webkit-user-select:none;user-select:none;touch-action:pan-y}.accord-item .accord-item__header .accord-item__title{flex:1 1 100%;font-size:14px;text-align:center}.accord-item .accord-item__header .accord-item__collapse{flex:0 0 1rem}.accord-item .accord-item__body{touch-action:pinch-zoom pan-y;transform-origin:top;-webkit-user-select:text;user-select:text}.accord-item .accord-item__body.closed{position:absolute}\n"], dependencies: [{ kind: "directive", type: i1$1.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "directive", type: AccordionItemImgDirective, selector: ".accord-item__header-img" }, { kind: "pipe", type: i1$1.AsyncPipe, name: "async" }], animations: [accordionItemAnimations.accordionItemBodyHeightCollapse], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngxd-accordion-item', animations: [accordionItemAnimations.accordionItemBodyHeightCollapse], changeDetection: ChangeDetectionStrategy.OnPush, template: "<!--\n/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */\n-->\n<ng-container *ngTemplateOutlet=\"itemTpl; context: { $implicit: isOpen$ | async }\"></ng-container>\n\n<ng-template #itemTpl let-isOpen>\n\t<article class=\"accord-item\">\n\t\t<header class=\"accord-item__header\" [class.opened]=\"isOpen\">\n\t\t\t<ng-container *ngTemplateOutlet=\"headerDefaultTmpl; context: { $implicit: isOpen }\"></ng-container>\n\t\t</header>\n\t\t<section class=\"accord-item__body\" [@openClose]=\"isOpen ? 'opened' : 'closed'\" (@openClose.start)=\"startAnim($event)\" (@openClose.done)=\"doneAnim($event)\">\n\t\t\t<ng-container *ngTemplateOutlet=\"getItemBodyTemplate($any(item.body), bodyDefaultTmpl); context: { $implicit: getItemBodyCtx($any(item.body)) }\"></ng-container>\n\t\t</section>\n\t</article>\n</ng-template>\n\n<ng-template #headerDefaultTmpl let-isOpen>\n\t<div class=\"header--control accord-item__logo\">\n\t\t<span class=\"accord-item__header--start\">\n\t\t\t<img class=\"accord-item__header-img accord-item__header--start-img\" />\n\t\t\t<span *ngIf=\"item.itemNum\">{{ item.itemNum }}.</span>\n\t\t</span>\n\t</div>\n\t<div class=\"header--control accord-item__title\">\n\t\t{{ item.title }}\n\t</div>\n\t<div class=\"header--control accord-item__collapse\">\n\t\t<span class=\"accord-item__header--end\" [class.active]=\"isOpen\">\n\t\t\t<!-- NOTE: img 'src' attr is bound in the `accordion-item-img.directive` -->\n\t\t\t<img class=\"accord-item__header-img accord-item__header--end-img\" [ngClass]=\"{ open: isOpen, close: !isOpen }\" />\n\t\t</span>\n\t</div>\n</ng-template>\n\n<ng-template #bodyDefaultTmpl let-defctx>\n\t{{ defctx }}\n\t<ng-content select=\".accord-item__footer\"></ng-content>\n</ng-template>\n", styles: [":host{--color-white: #fff;--ngxd-head-item-color: #056;--ngxd-head-item-color--active: #0095b3;--ngxd-head-item-color--opened: #002b33}/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */.accord-item{display:block;box-sizing:border-box;min-width:10rem;min-height:1rem;overflow:hidden}.accord-item .accord-item__header{display:flex;position:relative;flex-direction:row;min-height:1rem;max-height:50px;overflow:visible;transition:.6s ease;background-color:var(--ngxd-head-item-color);color:var(--color-white);-webkit-user-select:none;user-select:none}.accord-item .accord-item__header:hover,.accord-item .accord-item__header:active{background-color:var(--ngxd-head-item-color--active)!important;cursor:pointer}.accord-item .accord-item__header.opened{background-color:var(--ngxd-head-item-color--opened)!important}.accord-item .accord-item__header .accord-item__header--btn{max-width:2rem;border:none;background:transparent;font-size:x-large;text-align:center;vertical-align:middle}.accord-item .accord-item__header .accord-item__collapse--btn{padding-right:1px}.accord-item .accord-item__header .accord-item__header--start,.accord-item .accord-item__header .accord-item__header--end{display:flex;flex:0 0 1rem;align-items:center;justify-content:center;max-width:1.5rem;padding-left:1px}.accord-item .accord-item__header .accord-item__header--start .accord-item__header--start-img,.accord-item .accord-item__header .accord-item__header--end .accord-item__header--start-img{max-width:1rem;margin-right:.5rem}.accord-item .accord-item__header .accord-item__header--start>img,.accord-item .accord-item__header .accord-item__header--end>img{max-width:1.5rem}.accord-item .accord-item__header .accord-item__header--end{padding-right:1px;padding-left:0;will-change:transform}.accord-item .accord-item__header .accord-item__header--end.active{transform:rotate(180deg);transition:transform .3s ease-out}.accord-item .accord-item__header .accord-item__header--end:not(.active){transform:rotate(0);transition:transform .3s ease-out}.accord-item .accord-item__header .header--control{display:flex;align-items:center;margin:.1rem;padding:1rem;-webkit-user-select:none;user-select:none;touch-action:pan-y}.accord-item .accord-item__header .accord-item__title{flex:1 1 100%;font-size:14px;text-align:center}.accord-item .accord-item__header .accord-item__collapse{flex:0 0 1rem}.accord-item .accord-item__body{touch-action:pinch-zoom pan-y;transform-origin:top;-webkit-user-select:text;user-select:text}.accord-item .accord-item__body.closed{position:absolute}\n"] }]
        }] });

class AccordionItemDirective {
    constructor(hostCmp, hostElRef, itemStatusSvc, render, sanitizer, cd) {
        this.hostCmp = hostCmp;
        this.hostElRef = hostElRef;
        this.itemStatusSvc = itemStatusSvc;
        this.render = render;
        this.sanitizer = sanitizer;
        this.cd = cd;
        this.itemStyles = {
            headHeight: '50px',
            headBgColor: '#ccc',
            headColor: '#fff',
            bodyBgColor: '#fff',
            bodyColor: '#000',
            fontSize: '10px',
            bodyPadding: '0',
        };
        this.bodyDblclkClose = false;
        this.isNumbered = false;
        this.toggled = new EventEmitter();
        this.isOpen = false;
        this.hostDestroy$$ = new Subject();
        this.onClick = ([{ outerHTML }, { dataset }]) => ((outerHTML === null || outerHTML === void 0 ? void 0 : outerHTML.includes('header')) ? this._handleClick(Object.assign({}, dataset)) : void 0);
        this.onDClick = ([{ outerHTML }, { dataset }]) => ((outerHTML === null || outerHTML === void 0 ? void 0 : outerHTML.includes('accord-item__body')) ? this._handleClick(Object.assign({}, dataset)) : void 0);
        this._handleClick = (_a = { idx: -1 }) => {
            var { idx } = _a, rest = __rest(_a, ["idx"]);
            return this._toggle(+idx);
        };
        this._toggle = (itemId) => this.toggled.emit({ itemId, isOpen: !this.isOpen });
    }
    ngOnInit() {
        var _a, _b;
        this.hostCmp.item = Object.assign(Object.assign({}, this.item), { itemNum: this.isNumbered ? +this.item.itemId + 1 : null, body: typeof this.item.body === 'string'
                ? sanitizeHTML(this.item.body, this.sanitizer)
                : {
                    itemTemplate: (_a = this.item.body) === null || _a === void 0 ? void 0 : _a.itemTemplate,
                    itemBody: sanitizeHTML((_b = this.item.body) === null || _b === void 0 ? void 0 : _b.itemBody, this.sanitizer),
                } });
        this.hostCmp.isOpen$ = this.itemStatusSvc.itemsOpen$.pipe(takeUntil(this.hostDestroy$$), filter((val) => !!val && !!val.length), map((toggles) => toggles.find(({ itemId }) => itemId === +this.item.itemId)), pluck('isOpen'), tap((isOpen = false) => (this.isOpen = isOpen)));
    }
    ngAfterViewInit() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j;
        const nativeEl = this.hostElRef.nativeElement;
        const itemEl = nativeEl.getElementsByClassName('accord-item').item(0);
        const headEl = nativeEl.getElementsByClassName('accord-item__header').item(0);
        const bodyEl = nativeEl.getElementsByClassName('accord-item__body').item(0);
        {
            /** set up the accordion item header images\' sources */
            const headElLogoImgEl = headEl.getElementsByClassName('accord-item__header--start-img').item(0);
            const headElCloserImgEl = headEl.getElementsByClassName('accord-item__header--end-img').item(0);
            this.logo && this.render.setAttribute(headElLogoImgEl, 'data-src', this.logo);
            this.openSign && this.render.setAttribute(headElCloserImgEl, 'data-opensrc', this.openSign);
            this.closeSign && this.render.setAttribute(headElCloserImgEl, 'data-closesrc', this.closeSign);
            this.cd.detectChanges();
        }
        this.render.setStyle(itemEl, 'margin', (_a = this.itemStyles.margin) !== null && _a !== void 0 ? _a : '0');
        this.render.setStyle(itemEl, 'padding', (_b = this.itemStyles.padding) !== null && _b !== void 0 ? _b : '0');
        this.itemStyles.font && this.render.setStyle(itemEl, 'font', this.itemStyles.font);
        this.itemStyles.fontSize && this.render.setStyle(itemEl, 'font-size', this.itemStyles.fontSize);
        this.itemStyles.fontStyle && this.render.setStyle(itemEl, 'font-style', this.itemStyles.fontStyle);
        this.itemStyles.fontFamily && this.render.setStyle(itemEl, 'font-family', this.itemStyles.fontFamily);
        this.render.setStyle(itemEl, 'margin-bottom', this.itemStyles.marginBottom);
        this.render.setStyle(itemEl, 'margin-top', this.itemStyles.marginTop);
        this.itemStyles.headBgColor && nativeEl.style.setProperty('--ngxd-head-item-color', this.itemStyles.headBgColor);
        this.itemStyles.headHeight && this.render.setStyle(headEl, 'height', this.itemStyles.headHeight);
        this.itemStyles.headFont && this.render.setStyle(headEl, 'font', this.itemStyles.headFont);
        this.render.setStyle(headEl, 'font-size', (_c = this.itemStyles.headFontSize) !== null && _c !== void 0 ? _c : '1.1rem');
        this.render.setStyle(headEl, 'color', (_d = this.itemStyles.headColor) !== null && _d !== void 0 ? _d : '#ccc');
        this.render.setStyle(bodyEl, 'background-color', (_e = this.itemStyles.bodyBgColor) !== null && _e !== void 0 ? _e : 'rgba(200, 200, 200, 0.2)');
        this.render.setStyle(bodyEl, 'color', (_f = this.itemStyles.bodyColor) !== null && _f !== void 0 ? _f : '#000');
        this.render.setStyle(bodyEl, 'padding', (_g = this.itemStyles.bodyPadding) !== null && _g !== void 0 ? _g : '.1rem');
        this.render.setStyle(bodyEl, 'margin', (_h = this.itemStyles.bodyMargin) !== null && _h !== void 0 ? _h : '0');
        this.itemStyles.bodyFont && this.render.setStyle(bodyEl, 'font', this.itemStyles.bodyFont);
        this.render.setStyle(bodyEl, 'font-size', (_j = this.itemStyles.bodyFontSize) !== null && _j !== void 0 ? _j : '1rem');
        this.itemStyles.bodyTextAlign && this.render.setStyle(bodyEl, 'text-align', this.itemStyles.bodyTextAlign);
        this.render.setStyle(bodyEl, 'cursor', this.bodyDblclkClose ? 'grab' : 'default');
    }
    ngOnDestroy() {
        this.hostDestroy$$.next();
        this.hostDestroy$$.complete();
    }
}
AccordionItemDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemDirective, deps: [{ token: AccordionItemComponent }, { token: ElementRef }, { token: AccordionOpenService, host: true }, { token: i0.Renderer2 }, { token: i1.DomSanitizer }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
AccordionItemDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "14.2.9", type: AccordionItemDirective, selector: "[ngxdAccordionItem]", inputs: { item: ["ngxdAccordionItem", "item"], itemStyles: ["styling", "itemStyles"], logo: "logo", openSign: "openSign", closeSign: "closeSign", bodyDblclkClose: "bodyDblclkClose", isNumbered: "isNumbered" }, outputs: { toggled: "toggled" }, host: { listeners: { "dblclick": "onDClick([$event.target, $event.currentTarget])", "click": "onClick([$event.target, $event.currentTarget])" }, properties: { "class.opened": "isOpen" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionItemDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[ngxdAccordionItem]',
                    host: {
                        '[class.opened]': 'isOpen',
                        '(dblclick)': 'onDClick([$event.target, $event.currentTarget])',
                        '(click)': 'onClick([$event.target, $event.currentTarget])',
                    },
                }]
        }], ctorParameters: function () {
        return [{ type: AccordionItemComponent, decorators: [{
                        type: Inject,
                        args: [AccordionItemComponent]
                    }] }, { type: i0.ElementRef, decorators: [{
                        type: Inject,
                        args: [ElementRef]
                    }] }, { type: AccordionOpenService, decorators: [{
                        type: Host
                    }] }, { type: i0.Renderer2 }, { type: i1.DomSanitizer }, { type: i0.ChangeDetectorRef }];
    }, propDecorators: { item: [{
                type: Input,
                args: ['ngxdAccordionItem']
            }], itemStyles: [{
                type: Input,
                args: ['styling']
            }], logo: [{
                type: Input
            }], openSign: [{
                type: Input
            }], closeSign: [{
                type: Input
            }], bodyDblclkClose: [{
                type: Input
            }], isNumbered: [{
                type: Input
            }], toggled: [{
                type: Output
            }] } });

class AccordionComponent {
    constructor(itemsOpenSvc, hostEl, renderer) {
        this.itemsOpenSvc = itemsOpenSvc;
        this.hostEl = hostEl;
        this.renderer = renderer;
        this.accordionStyling = {
            numberedItems: false,
            isMultiShow: false,
            bodyDblclkCloseItems: false,
            maxWidth: '100%',
            itemsGuts: '1rem',
            margin: '0',
            itemStyling: {
                headBgColor: '#4197b2',
                headColor: '#fff',
                bodyBgColor: '#fff',
                bodyColor: '#000',
                margin: '0',
                padding: '0',
            },
        };
        this._bodyDblclkClose = false;
        this._isNumbered = false;
        this.multiSelect = false;
        this.onItemToggled = ({ itemId, isOpen } = { itemId: 0, isOpen: false }) => this.itemsOpenSvc.setItemsOpen(this.itemsOpenSvc.itemsOpenSnapshot.map(({ itemId: eId, isOpen: opened }) => (eId === +itemId
            ? { itemId, isOpen }
            : {
                itemId: eId,
                isOpen: this.multiSelect ? opened : false,
            })));
        this.closeAll = () => { var _a; return (_a = this.accordionItems) === null || _a === void 0 ? void 0 : _a.forEach((_a) => {
            var { itemId } = _a, rest = __rest(_a, ["itemId"]);
            return this.onItemToggled({ itemId, isOpen: false });
        }); };
        this.trackByFn = (_ind, _a) => {
            var { itemId } = _a, rest = __rest(_a, ["itemId"]);
            return +itemId;
        };
    }
    get id() {
        return `${this.attributes.id}`;
    }
    get name() {
        return this.attributes.name;
    }
    set accordionList(acc) {
        var _a;
        let [name, id] = [(!!acc && !!((_a = acc['name']) === null || _a === void 0 ? void 0 : _a.length) && acc.name) || 'Sample-Accordion', (!!acc && !!acc['id'] && acc.id) || `accordion_${++AccordionComponent.idx}`];
        this._accord = Object.assign({ id, name }, {
            items: acc === null || acc === void 0 ? void 0 : acc.items.map((item, i) => (Object.assign(Object.assign({}, item), { id: !!item.id && typeof item.id === 'string' ? item.id : `${id}__accord-item_${i}`, itemId: i }))),
        });
    }
    get accordionItems() {
        var _a;
        return (_a = this._accord) === null || _a === void 0 ? void 0 : _a.items;
    }
    set loadingTpl(val) {
        this._loadingTpl = val || this.defloadingTpl;
    }
    get loadingTpl() {
        var _a;
        return (_a = this._loadingTpl) !== null && _a !== void 0 ? _a : this.defloadingTpl;
    }
    ngOnInit() {
        var _a, _b, _c, _d, _e, _f, _g;
        this._bodyDblclkClose = (_a = !!this.accordionStyling.bodyDblclkCloseItems) !== null && _a !== void 0 ? _a : false;
        this.multiSelect = (_b = !!this.accordionStyling.isMultiShow) !== null && _b !== void 0 ? _b : false;
        this.itemsOpenSvc.itemsOpen$
            .pipe(filter((val) => !!(val === null || val === void 0 ? void 0 : val.length)), map(pluckOpenTogglesIdsToStr))
            .subscribe((ids) => (this._openedItems = ids));
        this._isNumbered = (_c = this.accordionStyling.numberedItems) !== null && _c !== void 0 ? _c : false;
        this._bodyDblclkClose = (_d = this.accordionStyling.bodyDblclkCloseItems) !== null && _d !== void 0 ? _d : false;
        let itemStyles = Array.isArray(this.accordionStyling.itemStyling)
            ? this.accordionStyling.itemStyling.reduce((accu = {}, curr) => (Object.assign(Object.assign({}, accu), curr)))
            : Object.assign({}, this.accordionStyling.itemStyling);
        const itemsGuts = (_e = this.accordionStyling.itemsGuts) !== null && _e !== void 0 ? _e : 0;
        itemStyles = Object.assign({ padding: '0', marginBottom: itemsGuts, marginTop: itemsGuts }, itemStyles);
        this._itemStyle = Object.entries(itemStyles)
            .map(([key, val]) => ({
            [key]: typeof val === 'number' ? `${val}px` : val,
        }))
            .reduce((accu, val) => (Object.assign(Object.assign({}, accu), val)));
        const accordEl = this.hostEl.nativeElement;
        this.renderer.setStyle(accordEl, 'max-width', (_f = this.accordionStyling.maxWidth) !== null && _f !== void 0 ? _f : '100%');
        this.renderer.setStyle(accordEl, 'margin', (_g = this.accordionStyling.margin) !== null && _g !== void 0 ? _g : '0');
    }
    ngOnChanges(changes) {
        Object.keys(changes).forEach((prop) => {
            var _a;
            if (prop === 'accordionList' && changes[prop].previousValue !== changes[prop].currentValue)
                this.itemsOpenSvc.setItemsOpen((_a = this.accordionItems) === null || _a === void 0 ? void 0 : _a.map(pluckIToggler));
        });
    }
    ngOnDestroy() {
        this.itemsOpenSvc.close();
    }
    get attributes() {
        const { id, name } = this._accord;
        return { id, name };
    }
}
AccordionComponent.idx = 0;
AccordionComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionComponent, deps: [{ token: AccordionOpenService, self: true }, { token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
AccordionComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.9", type: AccordionComponent, selector: "ngxd-accordion", inputs: { accordionList: "accordionList", openSign: "openSign", closeSign: "closeSign", listLogo: "listLogo", accordionStyling: "accordionStyling", loadingTpl: "loadingTpl" }, host: { properties: { "attr.data-items-opened": "this._openedItems", "attr.id": "this.id", "attr.name": "this.name" } }, viewQueries: [{ propertyName: "defloadingTpl", first: true, predicate: ["defloadingTpl"], descendants: true, read: TemplateRef, static: true }], exportAs: ["ngxdAccordion"], usesOnChanges: true, ngImport: i0, template: "<!--\n/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */ \n-->\n<div class=\"accordion\">\n\t<ng-container *ngIf=\"!!accordionItems; then itemsTmpl; else $any(loadingTpl)\"> </ng-container>\n</div>\n\n<ng-template #itemsTmpl>\n\t<ng-container *ngFor=\"let item of accordionItems; trackBy: trackByFn\" [ngTemplateOutlet]=\"accordItemTmpl\" [ngTemplateOutletContext]=\"{ $implicit: item }\"></ng-container>\n</ng-template>\n\n<ng-template #accordItemTmpl let-item>\n\t<ngxd-accordion-item\n\t\t[ngxdAccordionItem]=\"item\"\n\t\t[isNumbered]=\"_isNumbered\"\n\t\t[bodyDblclkClose]=\"_bodyDblclkClose\"\n\t\t[openSign]=\"openSign\"\n\t\t[closeSign]=\"closeSign\"\n\t\t[logo]=\"listLogo\"\n\t\t[styling]=\"_itemStyle\"\n\t\t[attr.data-idx]=\"item.itemId\"\n\t\t[id]=\"item.id\"\n\t\t(toggled)=\"onItemToggled($event)\"\n\t\t@accordItemsIn\n\t></ngxd-accordion-item>\n</ng-template>\n\n<ng-template #defloadingTpl>\n\t<style>\n\t\t.accordion-default-loader--tmpl {\n\t\t\tdisplay: block;\n\t\t\tborder-radius: 50%;\n\t\t\tbackground-color: transparent;\n\t\t\tmin-height: 50px;\n\t\t\tmin-width: 50px;\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg {\n\t\t\tfill: var(--dark-bg);\n\t\t\ttransform: rotate(90deg);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:first-of-type {\n\t\t\tfill: var(--darker-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(2) {\n\t\t\tfill: var(--accent-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(3) {\n\t\t\tfill: var(--dark-blue-color);\n\t\t}\n\t</style>\n\t<div class=\"accordion-default-loader--tmpl\" @spinnerIn>\n\t\t<svg width=\"51px\" height=\"50px\" viewBox=\"0 0 51 50\">\n\t\t\t<rect y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t\t<rect x=\"19\" y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0.2s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0.2s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t\t<rect x=\"38\" y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0.4s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0.4s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t</svg>\n\t</div>\n</ng-template>\n", styles: ["/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */:host{margin:auto}:host .accordion{display:flex;flex-direction:column;overflow:hidden;vertical-align:middle}:host .accordion-horizontal-menu{display:flex;flex-direction:row;width:100%;vertical-align:middle}:host .accordion-horizontal-menu ngxd-accordion-item{flex:1 1 auto}@media screen and (max-width: 720px){.accordion-horizontal-menu{flex-wrap:wrap}}\n", "\n\t\t.accordion-default-loader--tmpl {\n\t\t\tdisplay: block;\n\t\t\tborder-radius: 50%;\n\t\t\tbackground-color: transparent;\n\t\t\tmin-height: 50px;\n\t\t\tmin-width: 50px;\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg {\n\t\t\tfill: var(--dark-bg);\n\t\t\ttransform: rotate(90deg);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:first-of-type {\n\t\t\tfill: var(--darker-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(2) {\n\t\t\tfill: var(--accent-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(3) {\n\t\t\tfill: var(--dark-blue-color);\n\t\t}\n\t"], dependencies: [{ kind: "directive", type: i1$1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1$1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1$1.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: AccordionItemComponent, selector: "ngxd-accordion-item" }, { kind: "directive", type: AccordionItemDirective, selector: "[ngxdAccordionItem]", inputs: ["ngxdAccordionItem", "styling", "logo", "openSign", "closeSign", "bodyDblclkClose", "isNumbered"], outputs: ["toggled"] }], viewProviders: [AccordionOpenService], animations: [accordionAnimations.accordItemsIn, accordionAnimations.spinnerIn], changeDetection: i0.ChangeDetectionStrategy.OnPush });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngxd-accordion', exportAs: 'ngxdAccordion', animations: [accordionAnimations.accordItemsIn, accordionAnimations.spinnerIn], viewProviders: [AccordionOpenService], changeDetection: ChangeDetectionStrategy.OnPush, template: "<!--\n/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */ \n-->\n<div class=\"accordion\">\n\t<ng-container *ngIf=\"!!accordionItems; then itemsTmpl; else $any(loadingTpl)\"> </ng-container>\n</div>\n\n<ng-template #itemsTmpl>\n\t<ng-container *ngFor=\"let item of accordionItems; trackBy: trackByFn\" [ngTemplateOutlet]=\"accordItemTmpl\" [ngTemplateOutletContext]=\"{ $implicit: item }\"></ng-container>\n</ng-template>\n\n<ng-template #accordItemTmpl let-item>\n\t<ngxd-accordion-item\n\t\t[ngxdAccordionItem]=\"item\"\n\t\t[isNumbered]=\"_isNumbered\"\n\t\t[bodyDblclkClose]=\"_bodyDblclkClose\"\n\t\t[openSign]=\"openSign\"\n\t\t[closeSign]=\"closeSign\"\n\t\t[logo]=\"listLogo\"\n\t\t[styling]=\"_itemStyle\"\n\t\t[attr.data-idx]=\"item.itemId\"\n\t\t[id]=\"item.id\"\n\t\t(toggled)=\"onItemToggled($event)\"\n\t\t@accordItemsIn\n\t></ngxd-accordion-item>\n</ng-template>\n\n<ng-template #defloadingTpl>\n\t<style>\n\t\t.accordion-default-loader--tmpl {\n\t\t\tdisplay: block;\n\t\t\tborder-radius: 50%;\n\t\t\tbackground-color: transparent;\n\t\t\tmin-height: 50px;\n\t\t\tmin-width: 50px;\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg {\n\t\t\tfill: var(--dark-bg);\n\t\t\ttransform: rotate(90deg);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:first-of-type {\n\t\t\tfill: var(--darker-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(2) {\n\t\t\tfill: var(--accent-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(3) {\n\t\t\tfill: var(--dark-blue-color);\n\t\t}\n\t</style>\n\t<div class=\"accordion-default-loader--tmpl\" @spinnerIn>\n\t\t<svg width=\"51px\" height=\"50px\" viewBox=\"0 0 51 50\">\n\t\t\t<rect y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t\t<rect x=\"19\" y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0.2s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0.2s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t\t<rect x=\"38\" y=\"0\" width=\"13\" height=\"50\">\n\t\t\t\t<animate attributeName=\"height\" values=\"50;10;50\" begin=\"0.4s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t\t<animate attributeName=\"y\" values=\"0;20;0\" begin=\"0.4s\" dur=\"1s\" repeatCount=\"indefinite\" />\n\t\t\t</rect>\n\t\t</svg>\n\t</div>\n</ng-template>\n", styles: ["/*!\n * @ngx-dummy/Accordion-Simple library\n * Simple accordion created for angular / ionic projects.\n * https://github.com/ngx-dummy/accordion-simple\n *\n * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>\n * Published under GNU LGPLv3 License\n */:host{margin:auto}:host .accordion{display:flex;flex-direction:column;overflow:hidden;vertical-align:middle}:host .accordion-horizontal-menu{display:flex;flex-direction:row;width:100%;vertical-align:middle}:host .accordion-horizontal-menu ngxd-accordion-item{flex:1 1 auto}@media screen and (max-width: 720px){.accordion-horizontal-menu{flex-wrap:wrap}}\n", "\n\t\t.accordion-default-loader--tmpl {\n\t\t\tdisplay: block;\n\t\t\tborder-radius: 50%;\n\t\t\tbackground-color: transparent;\n\t\t\tmin-height: 50px;\n\t\t\tmin-width: 50px;\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg {\n\t\t\tfill: var(--dark-bg);\n\t\t\ttransform: rotate(90deg);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:first-of-type {\n\t\t\tfill: var(--darker-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(2) {\n\t\t\tfill: var(--accent-color);\n\t\t}\n\t\t.accordion-default-loader--tmpl > svg rect:nth-of-type(3) {\n\t\t\tfill: var(--dark-blue-color);\n\t\t}\n\t"] }]
        }], ctorParameters: function () {
        return [{ type: AccordionOpenService, decorators: [{
                        type: Self
                    }] }, { type: i0.ElementRef }, { type: i0.Renderer2 }];
    }, propDecorators: { defloadingTpl: [{
                type: ViewChild,
                args: ['defloadingTpl', { read: TemplateRef, static: true }]
            }], _openedItems: [{
                type: HostBinding,
                args: ['attr.data-items-opened']
            }], id: [{
                type: HostBinding,
                args: ['attr.id']
            }], name: [{
                type: HostBinding,
                args: ['attr.name']
            }], accordionList: [{
                type: Input
            }], openSign: [{
                type: Input
            }], closeSign: [{
                type: Input
            }], listLogo: [{
                type: Input
            }], accordionStyling: [{
                type: Input
            }], loadingTpl: [{
                type: Input
            }] } });

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */
class AccordionModule {
}
AccordionModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
AccordionModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.9", ngImport: i0, type: AccordionModule, declarations: [AccordionComponent, AccordionItemComponent, AccordionItemDirective, AccordionItemImgDirective], imports: [CommonModule, HttpClientModule], exports: [AccordionComponent] });
AccordionModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionModule, imports: [CommonModule, HttpClientModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.9", ngImport: i0, type: AccordionModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule, HttpClientModule],
                    declarations: [AccordionComponent, AccordionItemComponent, AccordionItemDirective, AccordionItemImgDirective],
                    exports: [AccordionComponent],
                }]
        }] });

/*!
 * @ngx-dummy/Accordion-Simple library
 * Simple accordion created for angular / ionic projects.
 * https://github.com/ngx-dummy/accordion-simple
 *
 * Copyright  Vladimir Ovsyukov <ovsyukov@yandex.com>
 * Published under GNU LGPLv3 License
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AccordionComponent, AccordionModule };
//# sourceMappingURL=ngx-dummy-accordion-simple.mjs.map
